@@ -1,5 +1,5 @@
 /* Copyright (c) 2002, 2003, 2004 Marek Michalkiewicz
-   Copyright (c) 2005, Bjoern Haase
+   Copyright (c) 2005, 2006 Bjoern Haase
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: eeprom.h,v 1.17 2005/09/13 13:29:54 joerg_wunsch Exp $ */
+/* $Id: eeprom.h,v 1.17.2.1 2006/02/26 21:51:04 aesok Exp $ */
 
 /*
    eeprom.h
@@ -299,7 +299,7 @@ void
 eeprom_write_word (uint16_t *addr,uint16_t value)
 {
   asm volatile (
-#if __AVR_ENHANCED__
+#if __AVR_HAVE_MOVW__
          "movw __tmp_reg__,%A1" CR_TAB
 #else
          "mov __tmp_reg__,%A1"      CR_TAB
