@@ -1,4 +1,4 @@
-/* Copyright (c) 2002,2003 Marek Michalkiewicz, Joerg Wunsch
+/* Copyright (c) 2002,2003,2005,2006, Marek Michalkiewicz, Joerg Wunsch
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io.h,v 1.24.2.1 2005/12/16 21:26:26 aesok Exp $ */
+/* $Id: io.h,v 1.24.2.7 2006/04/19 16:53:25 aesok Exp $ */
 
 /** \defgroup avr_io <avr/io.h>: AVR device-specific IO definitions
     \code #include <avr/io.h> \endcode
@@ -85,6 +85,18 @@
 
 #include <avr/sfr_defs.h>
 
+#ifndef __AVR_HAVE_MOVW__
+#  if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
+#   define __AVR_HAVE_MOVW__ 1
+#  endif
+#endif
+
+#ifndef __AVR_HAVE_LPMX__
+# if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
+#  define __AVR_HAVE_LPMX__ 1
+# endif
+#endif
+
 /*
  * Registers common to all AVR devices.
  */
@@ -182,12 +194,22 @@
 #  include <avr/iocan64.h>
 #elif defined (__AVR_AT90CAN128__)
 #  include <avr/iocan128.h>
+#elif defined (__AVR_AT90USB646__)
+#  include <avr/iousb646.h>
+#elif defined (__AVR_AT90USB647__)
+#  include <avr/iousb647.h>
+#elif defined (__AVR_AT90USB1286__)
+#  include <avr/iousb1286.h>
+#elif defined (__AVR_AT90USB1287__)
+#  include <avr/iousb1287.h>
 #elif defined (__AVR_ATmega64__)
 #  include <avr/iom64.h>
 #elif defined (__AVR_ATmega640__)
 #  include <avr/iom640.h>
 #elif defined (__AVR_ATmega644__)
 #  include <avr/iom644.h>
+#elif defined (__AVR_ATmega644P__)
+#  include <avr/iom644.h>
 #elif defined (__AVR_ATmega645__)
 #  include <avr/iom645.h>
 #elif defined (__AVR_ATmega6450__)
@@ -202,7 +224,7 @@
 #  include <avr/iom32.h>
 #elif defined (__AVR_ATmega323__)
 #  include <avr/iom323.h>
-#elif defined (__AVR_ATmega324__)
+#elif defined (__AVR_ATmega324P__)
 #  include <avr/iom324.h>
 #elif defined (__AVR_ATmega325__)
 #  include <avr/iom325.h>
@@ -212,6 +234,8 @@
 #  include <avr/iom329.h>
 #elif defined (__AVR_ATmega3290__)
 #  include <avr/iom3290.h>
+#elif defined (__AVR_ATmega406__)
+#  include <avr/iom406.h>
 #elif defined (__AVR_ATmega16__)
 #  include <avr/iom16.h>
 #elif defined (__AVR_ATmega161__)
@@ -220,7 +244,7 @@
 #  include <avr/iom162.h>
 #elif defined (__AVR_ATmega163__)
 #  include <avr/iom163.h>
-#elif defined (__AVR_ATmega164__)
+#elif defined (__AVR_ATmega164P__)
 #  include <avr/iom164.h>
 #elif defined (__AVR_ATmega165__)
 #  include <avr/iom165.h>
@@ -278,6 +302,12 @@
 #  include <avr/iotn44.h>
 #elif defined (__AVR_ATtiny84__)
 #  include <avr/iotn84.h>
+#elif defined (__AVR_ATtiny261__)
+#  include <avr/iotn261.h>
+#elif defined (__AVR_ATtiny461__)
+#  include <avr/iotn461.h>
+#elif defined (__AVR_ATtiny861__)
+#  include <avr/iotn861.h>
 /* avr1: the following only supported for assembler programs */
 #elif defined (__AVR_ATtiny28__)
 #  include <avr/iotn28.h>
